@@ -325,7 +325,7 @@ gvm_device_autorun (const char *udi)
 	if (gvm_check_photos (udi, device, mount_point))
 		goto out;
 
-	if (config.autorun == TRUE) {
+	if (config.autorun == TRUE && config.autorun_path) {
 		char **autorun_fns;
 		int i;
 
@@ -473,13 +473,13 @@ gvm_run_cdburner (const char *device, const char *mount_point)
 static gboolean
 gvm_device_is_writer (const char *udi)
 {
-	if (hal_device_get_property_int (udi, "storage.cdr"))
+	if (hal_device_get_property_int (udi, "storage.cdr") == 1)
 		return 1;
-	else if (hal_device_get_property_int (udi, "storage.cdrw"))
+	else if (hal_device_get_property_int (udi, "storage.cdrw") == 1)
 		return 1;
-	else if (hal_device_get_property_int (udi, "storage.dvdr"))
+	else if (hal_device_get_property_int (udi, "storage.dvdr") == 1)
 		return 1;
-	else if (hal_device_get_property_int (udi, "storage.dvdram"))
+	else if (hal_device_get_property_int (udi, "storage.dvdram") == 1)
 		return 1;
 
 	return 0;
@@ -510,7 +510,7 @@ gvm_cdrom_policy (const char *udi)
 		gvm_run_cdplayer (device, device);
 	} else if (!strcmp (type, "mixed")) {
 		gvm_ask_mixed (udi);
-	} else if (!strcmp (type, "iso9660")) {
+	} else if (!strcmp (type, "data")) {
 		if (config.automount_media)
 			gvm_device_mount (device);
 	} else if (!strcmp (type, "blank")) {
